#[repr(i32)]pub enum NotificationType {
Show 14 variants
NotifyOnKeystroke = 1,
NotifyOnScreenUpdate = 2,
NotifyOnPrompt = 3,
NotifyOnLocationChange = 4,
NotifyOnCustomEscapeSequence = 5,
NotifyOnVariableChange = 12,
KeystrokeFilter = 14,
NotifyOnNewSession = 6,
NotifyOnTerminateSession = 7,
NotifyOnLayoutChange = 8,
NotifyOnFocusChange = 9,
NotifyOnServerOriginatedRpc = 10,
NotifyOnBroadcastChange = 11,
NotifyOnProfileChange = 13,
}Variants
NotifyOnKeystroke = 1
NotifyOnScreenUpdate = 2
NotifyOnPrompt = 3
NotifyOnLocationChange = 4
NotifyOnCustomEscapeSequence = 5
NotifyOnVariableChange = 12
KeystrokeFilter = 14
NotifyOnNewSession = 6
NotifyOnTerminateSession = 7
NotifyOnLayoutChange = 8
NotifyOnFocusChange = 9
NotifyOnServerOriginatedRpc = 10
NotifyOnBroadcastChange = 11
NotifyOnProfileChange = 13
Implementations
Sourceimpl NotificationType
impl NotificationType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.