CellStyle

Struct CellStyle 

pub struct CellStyle {
Show 16 fields pub bold: Option<bool>, pub faint: Option<bool>, pub italic: Option<bool>, pub blink: Option<bool>, pub underline: Option<bool>, pub strikethrough: Option<bool>, pub invisible: Option<bool>, pub inverse: Option<bool>, pub guarded: Option<bool>, pub image: Option<i32>, pub underline_color: Option<RgbColor>, pub block_id: Option<String>, pub url: Option<Url>, pub repeats: Option<u32>, pub fg_color: Option<FgColor>, pub bg_color: Option<BgColor>,
}

Fields

bold: Option<bool>faint: Option<bool>italic: Option<bool>blink: Option<bool>underline: Option<bool>strikethrough: Option<bool>invisible: Option<bool>inverse: Option<bool>guarded: Option<bool>image: Option<i32>underline_color: Option<RgbColor>block_id: Option<String>url: Option<Url>repeats: Option<u32>fg_color: Option<FgColor>bg_color: Option<BgColor>

Implementations

Source

impl CellStyle

pub fn bold(&self) -> bool

Returns the value of bold, or the default value if bold is unset.

pub fn faint(&self) -> bool

Returns the value of faint, or the default value if faint is unset.

pub fn italic(&self) -> bool

Returns the value of italic, or the default value if italic is unset.

Returns the value of blink, or the default value if blink is unset.

pub fn underline(&self) -> bool

Returns the value of underline, or the default value if underline is unset.

pub fn strikethrough(&self) -> bool

Returns the value of strikethrough, or the default value if strikethrough is unset.

pub fn invisible(&self) -> bool

Returns the value of invisible, or the default value if invisible is unset.

pub fn inverse(&self) -> bool

Returns the value of inverse, or the default value if inverse is unset.

pub fn guarded(&self) -> bool

Returns the value of guarded, or the default value if guarded is unset.

pub fn image(&self) -> ImagePlaceholderType

Returns the enum value of image, or the default if the field is unset or set to an invalid enum value.

pub fn set_image(&mut self, value: ImagePlaceholderType)

Sets image to the provided enum value.

pub fn block_id(&self) -> &str

Returns the value of block_id, or the default value if block_id is unset.

pub fn repeats(&self) -> u32

Returns the value of repeats, or the default value if repeats is unset.