pub struct CreateTabResponse {
pub status: Option<i32>,
pub window_id: Option<String>,
pub tab_id: Option<i32>,
pub session_id: Option<String>,
}Fields
status: Option<i32>window_id: Option<String>tab_id: Option<i32>session_id: Option<String>Implementations
Sourceimpl CreateTabResponse
impl CreateTabResponse
Sourcepub fn status(&self) -> Status
pub fn status(&self) -> Status
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: Status)
pub fn set_status(&mut self, value: Status)
Sets status to the provided enum value.
Sourcepub fn window_id(&self) -> &str
pub fn window_id(&self) -> &str
Returns the value of window_id, or the default value if window_id is unset.
Sourcepub fn tab_id(&self) -> i32
pub fn tab_id(&self) -> i32
Returns the value of tab_id, or the default value if tab_id is unset.
Sourcepub fn session_id(&self) -> &str
pub fn session_id(&self) -> &str
Returns the value of session_id, or the default value if session_id is unset.