pub struct KeystrokeNotification {
pub characters: Option<String>,
pub characters_ignoring_modifiers: Option<String>,
pub modifiers: Vec<i32>,
pub key_code: Option<i32>,
pub session: Option<String>,
pub action: Option<i32>,
}Fields
characters: Option<String>characters_ignoring_modifiers: Option<String>modifiers: Vec<i32>key_code: Option<i32>session: Option<String>action: Option<i32>Implementations
Sourceimpl KeystrokeNotification
impl KeystrokeNotification
Sourcepub fn characters(&self) -> &str
pub fn characters(&self) -> &str
Returns the value of characters, or the default value if characters is unset.
Sourcepub fn characters_ignoring_modifiers(&self) -> &str
pub fn characters_ignoring_modifiers(&self) -> &str
Returns the value of characters_ignoring_modifiers, or the default value if characters_ignoring_modifiers is unset.
Sourcepub fn modifiers(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Modifiers>>
pub fn modifiers( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Modifiers>>
Returns an iterator which yields the valid enum values contained in modifiers.
Sourcepub fn push_modifiers(&mut self, value: Modifiers)
pub fn push_modifiers(&mut self, value: Modifiers)
Appends the provided enum value to modifiers.
Sourcepub fn key_code(&self) -> i32
pub fn key_code(&self) -> i32
Returns the value of key_code, or the default value if key_code is unset.
Sourcepub fn session(&self) -> &str
pub fn session(&self) -> &str
Returns the value of session, or the default value if session is unset.
Sourcepub fn action(&self) -> Action
pub fn action(&self) -> Action
Returns the enum value of action, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: Action)
pub fn set_action(&mut self, value: Action)
Sets action to the provided enum value.