pub struct KeystrokePattern {
pub required_modifiers: Vec<i32>,
pub forbidden_modifiers: Vec<i32>,
pub keycodes: Vec<i32>,
pub characters: Vec<String>,
pub characters_ignoring_modifiers: Vec<String>,
}Fields
required_modifiers: Vec<i32>forbidden_modifiers: Vec<i32>keycodes: Vec<i32>characters: Vec<String>characters_ignoring_modifiers: Vec<String>Implementations
Sourceimpl KeystrokePattern
impl KeystrokePattern
Sourcepub fn required_modifiers(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Modifiers>>
pub fn required_modifiers( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Modifiers>>
Returns an iterator which yields the valid enum values contained in required_modifiers.
Sourcepub fn push_required_modifiers(&mut self, value: Modifiers)
pub fn push_required_modifiers(&mut self, value: Modifiers)
Appends the provided enum value to required_modifiers.
Sourcepub fn forbidden_modifiers(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Modifiers>>
pub fn forbidden_modifiers( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Modifiers>>
Returns an iterator which yields the valid enum values contained in forbidden_modifiers.
Sourcepub fn push_forbidden_modifiers(&mut self, value: Modifiers)
pub fn push_forbidden_modifiers(&mut self, value: Modifiers)
Appends the provided enum value to forbidden_modifiers.