pub struct LineContents {
pub text: Option<String>,
pub code_points_per_cell: Vec<CodePointsPerCell>,
pub continuation: Option<i32>,
pub style: Vec<CellStyle>,
}Fields
text: Option<String>code_points_per_cell: Vec<CodePointsPerCell>continuation: Option<i32>style: Vec<CellStyle>Implementations
Sourceimpl LineContents
impl LineContents
Sourcepub fn continuation(&self) -> Continuation
pub fn continuation(&self) -> Continuation
Returns the enum value of continuation, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_continuation(&mut self, value: Continuation)
pub fn set_continuation(&mut self, value: Continuation)
Sets continuation to the provided enum value.