pub struct NotificationRequest {
pub session: Option<String>,
pub subscribe: Option<bool>,
pub notification_type: Option<i32>,
pub arguments: Option<Arguments>,
}Fields
session: Option<String>subscribe: Option<bool>notification_type: Option<i32>arguments: Option<Arguments>Implementations
Sourceimpl NotificationRequest
impl NotificationRequest
Sourcepub fn session(&self) -> &str
pub fn session(&self) -> &str
Returns the value of session, or the default value if session is unset.
Sourcepub fn subscribe(&self) -> bool
pub fn subscribe(&self) -> bool
Returns the value of subscribe, or the default value if subscribe is unset.
Sourcepub fn notification_type(&self) -> NotificationType
pub fn notification_type(&self) -> NotificationType
Returns the enum value of notification_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_notification_type(&mut self, value: NotificationType)
pub fn set_notification_type(&mut self, value: NotificationType)
Sets notification_type to the provided enum value.