pub struct SplitPaneRequest {
pub session: Option<String>,
pub split_direction: Option<i32>,
pub before: Option<bool>,
pub profile_name: Option<String>,
pub custom_profile_properties: Vec<ProfileProperty>,
}Fields
session: Option<String>split_direction: Option<i32>before: Option<bool>profile_name: Option<String>custom_profile_properties: Vec<ProfileProperty>Implementations
Sourceimpl SplitPaneRequest
impl SplitPaneRequest
Sourcepub fn session(&self) -> &str
pub fn session(&self) -> &str
Returns the value of session, or the default value if session is unset.
Sourcepub fn split_direction(&self) -> SplitDirection
pub fn split_direction(&self) -> SplitDirection
Returns the enum value of split_direction, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_split_direction(&mut self, value: SplitDirection)
pub fn set_split_direction(&mut self, value: SplitDirection)
Sets split_direction to the provided enum value.
Sourcepub fn before(&self) -> bool
pub fn before(&self) -> bool
Returns the value of before, or the default value if before is unset.
Sourcepub fn profile_name(&self) -> &str
pub fn profile_name(&self) -> &str
Returns the value of profile_name, or the default value if profile_name is unset.