pub struct VariableChangedNotification {
pub scope: Option<i32>,
pub identifier: Option<String>,
pub name: Option<String>,
pub json_new_value: Option<String>,
}Fields
scope: Option<i32>identifier: Option<String>name: Option<String>json_new_value: Option<String>Implementations
Sourceimpl VariableChangedNotification
impl VariableChangedNotification
Sourcepub fn scope(&self) -> VariableScope
pub fn scope(&self) -> VariableScope
Returns the enum value of scope, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_scope(&mut self, value: VariableScope)
pub fn set_scope(&mut self, value: VariableScope)
Sets scope to the provided enum value.
Sourcepub fn identifier(&self) -> &str
pub fn identifier(&self) -> &str
Returns the value of identifier, or the default value if identifier is unset.
Sourcepub fn json_new_value(&self) -> &str
pub fn json_new_value(&self) -> &str
Returns the value of json_new_value, or the default value if json_new_value is unset.