pub struct Credentials {
pub cookie: String,
pub key: String,
}Expand description
Cookie and key pair used to authenticate with the iTerm2 WebSocket API.
Credentials are zeroized from memory when dropped. The Debug implementation
redacts the actual values to prevent accidental credential leakage in logs.
Fields
key: StringTrait Implementations
Sourceimpl Debug for Credentials
impl Debug for Credentials
Sourceimpl Drop for Credentials
impl Drop for Credentials