pub struct CellStyle {Show 16 fields
pub bold: Option<bool>,
pub faint: Option<bool>,
pub italic: Option<bool>,
pub blink: Option<bool>,
pub underline: Option<bool>,
pub strikethrough: Option<bool>,
pub invisible: Option<bool>,
pub inverse: Option<bool>,
pub guarded: Option<bool>,
pub image: Option<i32>,
pub underline_color: Option<RgbColor>,
pub block_id: Option<String>,
pub url: Option<Url>,
pub repeats: Option<u32>,
pub fg_color: Option<FgColor>,
pub bg_color: Option<BgColor>,
}Fields
bold: Option<bool>faint: Option<bool>italic: Option<bool>blink: Option<bool>underline: Option<bool>strikethrough: Option<bool>invisible: Option<bool>inverse: Option<bool>guarded: Option<bool>image: Option<i32>underline_color: Option<RgbColor>block_id: Option<String>url: Option<Url>repeats: Option<u32>fg_color: Option<FgColor>bg_color: Option<BgColor>Implementations
Sourceimpl CellStyle
impl CellStyle
Sourcepub fn faint(&self) -> bool
pub fn faint(&self) -> bool
Returns the value of faint, or the default value if faint is unset.
Sourcepub fn italic(&self) -> bool
pub fn italic(&self) -> bool
Returns the value of italic, or the default value if italic is unset.
Sourcepub fn blink(&self) -> bool
pub fn blink(&self) -> bool
Returns the value of blink, or the default value if blink is unset.
Sourcepub fn underline(&self) -> bool
pub fn underline(&self) -> bool
Returns the value of underline, or the default value if underline is unset.
Sourcepub fn strikethrough(&self) -> bool
pub fn strikethrough(&self) -> bool
Returns the value of strikethrough, or the default value if strikethrough is unset.
Sourcepub fn invisible(&self) -> bool
pub fn invisible(&self) -> bool
Returns the value of invisible, or the default value if invisible is unset.
Sourcepub fn inverse(&self) -> bool
pub fn inverse(&self) -> bool
Returns the value of inverse, or the default value if inverse is unset.
Sourcepub fn guarded(&self) -> bool
pub fn guarded(&self) -> bool
Returns the value of guarded, or the default value if guarded is unset.
Sourcepub fn image(&self) -> ImagePlaceholderType
pub fn image(&self) -> ImagePlaceholderType
Returns the enum value of image, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_image(&mut self, value: ImagePlaceholderType)
pub fn set_image(&mut self, value: ImagePlaceholderType)
Sets image to the provided enum value.